package repositories

import "gitea.michaelthomson.dev/mthomson/habits/internal/models"

type InMemoryTodoRepository struct {
	db map[int64]*models.Todo
	id int64
}

func NewInMemoryTodoRepository() InMemoryTodoRepository {
	return InMemoryTodoRepository{
		db: make(map[int64]*models.Todo),
		id: 1,
	}
}


func (r *InMemoryTodoRepository) GetById(id int64) (*models.Todo, error) {
	todo, found := r.db[id]

	if !found {
		return todo, ErrNotFound
	}

	return todo, nil
}

func (r *InMemoryTodoRepository) Create(todo *models.Todo) error {
	todo.Id = r.id
	r.db[r.id] = todo
	r.id++

	return nil
}

func (r *InMemoryTodoRepository) Update(todo *models.Todo) error {
	_, found := r.db[todo.Id]

	if !found {
		return ErrNotFound
	}

	r.db[todo.Id] = todo

	return nil
}

func (r *InMemoryTodoRepository) Delete(id int64) error {
	_, found := r.db[id]

	if !found {
		return ErrNotFound
	}

	delete(r.db, id)

	return nil
}
