package repositories

import (
	"database/sql"

	"gitea.michaelthomson.dev/mthomson/habits/internal/models"
)

type SqliteTodoRepository struct {
	db *sql.DB
}

func NewSqliteTodoRepository(db *sql.DB) SqliteTodoRepository {
	return SqliteTodoRepository{
		db: db,
	}
}

func (r *SqliteTodoRepository) GetById(id int64) (*models.Todo, error) {
	todo := &models.Todo{}

	row := r.db.QueryRow("SELECT * FROM todo WHERE id = ?;", id)
	err := row.Scan(todo.Id, todo.Name, todo.Done)

	if err != nil {
		if err == sql.ErrNoRows {
			return todo, ErrNotFound
		}

		return todo, err
	}

	return todo, nil
}

func (r *SqliteTodoRepository) Create(todo *models.Todo) error {
	result, err := r.db.Exec("INSERT INTO todo (name, done) VALUES (?, ?)", todo.Name, todo.Done)

	if err != nil {
		return err
	}

	id, err := result.LastInsertId()

	if err != nil {
		return err
	}

	todo.Id = id

	return nil
}

func (r *SqliteTodoRepository) Update(todo *models.Todo) error {
	result, err := r.db.Exec("UPDATE todo SET name = ?, done = ? WHERE id = ?", todo.Name, todo.Done, todo.Id)

	if err != nil {
		return err
	}

	rowsAffected, err := result.RowsAffected()

	if err != nil {
		return err
	}

	if rowsAffected == 0 {
		return ErrNotFound
	}

	return nil
}

func (r *SqliteTodoRepository) Delete(id int64) error {
	result, err := r.db.Exec("DELETE FROM todo WHERE id = ?", id)

	if err != nil {
		return err
	}

	rowsAffected, err := result.RowsAffected()

	if err != nil {
		return err
	}

	if rowsAffected == 0 {
		return ErrNotFound
	}

	return nil
}
